Otherize

Struct Otherize 

pub struct Otherize<'a, T: Token, F: FnMut(T)>(/* private fields */);
Struct that allows to write! and format! by converting the string to Tokens and passes them to a closure. All tokens have CommandCode::Other except for space characters. For example, write!(Tokenizer::new(|t| vec.push(t), "ab c") will push four tokens to vec, where the first, second and fourth have CommandCode::Other and the third has CommandCode::Space.

Implementations

Source

impl<'a, T: Token, F: FnMut(T)> Otherize<'a, T, F>

pub fn new(f: &'a mut F) -> Self

Creates a new Otherize from a closure.